/* SerializablePropertyFloatTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializablePropertyFloatTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST (serializable_property_float_test_get_type ())
#define SERIALIZABLE_PROPERTY_FLOAT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTest))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTestClass))
#define IS_SERIALIZABLE_PROPERTY_FLOAT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST))
#define IS_SERIALIZABLE_PROPERTY_FLOAT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTestClass))

typedef struct _SerializablePropertyFloatTest SerializablePropertyFloatTest;
typedef struct _SerializablePropertyFloatTestClass SerializablePropertyFloatTestClass;
typedef struct _SerializablePropertyFloatTestPrivate SerializablePropertyFloatTestPrivate;

#define SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE (serializable_property_float_test_float_node_get_type ())
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNodeClass))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_IS_FLOAT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_IS_FLOAT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNodeClass))

typedef struct _SerializablePropertyFloatTestFloatNode SerializablePropertyFloatTestFloatNode;
typedef struct _SerializablePropertyFloatTestFloatNodeClass SerializablePropertyFloatTestFloatNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializablePropertyFloatTestFloatNodePrivate SerializablePropertyFloatTestFloatNodePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyFloatTest {
	GXmlTest parent_instance;
	SerializablePropertyFloatTestPrivate * priv;
};

struct _SerializablePropertyFloatTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyFloatTestFloatNode {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyFloatTestFloatNodePrivate * priv;
};

struct _SerializablePropertyFloatTestFloatNodeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyFloatTestFloatNodePrivate {
	GXmlSerializableFloat* _float_value;
	gchar* _name;
};


static gpointer serializable_property_float_test_parent_class = NULL;
static gpointer serializable_property_float_test_float_node_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_float_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_PROPERTY_FLOAT_TEST_DUMMY_PROPERTY
};
void serializable_property_float_test_add_tests (void);
static void __lambda139_ (void);
GType serializable_property_float_test_float_node_get_type (void) G_GNUC_CONST;
SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_new (void);
SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_construct (GType object_type);
static void ___lambda139__gtest_func (void);
static void __lambda140_ (void);
void serializable_property_float_test_float_node_set_float_value (SerializablePropertyFloatTestFloatNode* self, GXmlSerializableFloat* value);
GXmlSerializableFloat* serializable_property_float_test_float_node_get_float_value (SerializablePropertyFloatTestFloatNode* self);
static void ___lambda140__gtest_func (void);
static void __lambda141_ (void);
static void ___lambda141__gtest_func (void);
static void __lambda142_ (void);
static void ___lambda142__gtest_func (void);
static void __lambda143_ (void);
static void ___lambda143__gtest_func (void);
SerializablePropertyFloatTest* serializable_property_float_test_new (void);
SerializablePropertyFloatTest* serializable_property_float_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNodePrivate))
enum  {
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_DUMMY_PROPERTY,
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE,
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME
};
static gchar* serializable_property_float_test_float_node_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_float_test_float_node_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_float_test_float_node_real_property_use_nick (GXmlSerializableObjectModel* base);
const gchar* serializable_property_float_test_float_node_get_name (SerializablePropertyFloatTestFloatNode* self);
void serializable_property_float_test_float_node_set_name (SerializablePropertyFloatTestFloatNode* self, const gchar* value);
static void serializable_property_float_test_float_node_finalize (GObject* obj);
static void _vala_serializable_property_float_test_float_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_property_float_test_float_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 149 "SerializablePropertyFloatTest.c"
}


static void __lambda139_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyFloatTestFloatNode* bn = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlNode* b = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_ = NULL;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp0_ = serializable_property_float_test_float_node_new ();
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		bn = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc = _tmp1_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bn, (GXmlNode*) doc, &_inner_error_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp3_ = _tmp2_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp3_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 194 "SerializablePropertyFloatTest.c"
			goto __catch22_g_error;
		}
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp5_ = _tmp4_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp7_ = _tmp6_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp7_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp7_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp5_);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp9_ = _tmp8_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (_tmp10_ == NULL) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp9_);
#line 221 "SerializablePropertyFloatTest.c"
		}
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		element = _tmp10_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "FloatValue");
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		b = _tmp11_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (b == NULL, "b == null");
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		s = _tmp12_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (s);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (bn);
#line 247 "SerializablePropertyFloatTest.c"
	}
	goto __finally22;
	__catch22_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		e = _inner_error_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_inner_error_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp13_ = e->message;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp15_ = g_strconcat ("ERROR: ", _tmp14_, NULL);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp16_ = _tmp15_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp16_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp16_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 277 "SerializablePropertyFloatTest.c"
	}
	__finally22:
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error_);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		return;
#line 288 "SerializablePropertyFloatTest.c"
	}
}


static void ___lambda139__gtest_func (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	__lambda139_ ();
#line 296 "SerializablePropertyFloatTest.c"
}


static gdouble double_parse (const gchar* str) {
	gdouble result = 0.0;
	const gchar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
#line 869 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0.0);
#line 870 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 870 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = g_ascii_strtod (_tmp0_, NULL);
#line 870 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 870 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 314 "SerializablePropertyFloatTest.c"
}


static void __lambda140_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyFloatTestFloatNode* bn = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlElement* _tmp14_ = NULL;
		GXmlNode* b = NULL;
		GXmlElement* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* s = NULL;
		GXmlElement* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp21_ = NULL;
		GXmlSerializableFloat* _tmp22_ = NULL;
		GXmlSerializableFloat* _tmp23_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp24_ = NULL;
		GXmlSerializableFloat* _tmp25_ = NULL;
		GXmlSerializableFloat* _tmp26_ = NULL;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp27_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp28_ = NULL;
		GXmlGDocument* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlGDocument* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GXmlNode* _tmp39_ = NULL;
		GXmlElement* _tmp40_ = NULL;
		GXmlNode* b2 = NULL;
		GXmlElement* _tmp41_ = NULL;
		GXmlNode* _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp44_ = NULL;
		GXmlSerializableFloat* _tmp45_ = NULL;
		GXmlSerializableFloat* _tmp46_ = NULL;
		gfloat _tmp47_ = 0.0F;
		GXmlNode* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp54_ = NULL;
		GXmlSerializableFloat* _tmp55_ = NULL;
		GXmlSerializableFloat* _tmp56_ = NULL;
		gfloat _tmp57_ = 0.0F;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		GXmlNode* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gdouble _tmp66_ = 0.0;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		GXmlNode* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		gdouble _tmp73_ = 0.0;
		gchar* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		GXmlNode* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		gchar* _tmp79_ = NULL;
		gdouble _tmp80_ = 0.0;
		gchar* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp83_ = NULL;
		GXmlSerializableFloat* _tmp84_ = NULL;
		GXmlSerializableFloat* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		gchar* _tmp87_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp88_ = NULL;
		GXmlSerializableFloat* _tmp89_ = NULL;
		GXmlSerializableFloat* _tmp90_ = NULL;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp91_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp92_ = NULL;
		GXmlGDocument* _tmp93_ = NULL;
		GXmlNode* _tmp94_ = NULL;
		GXmlNode* _tmp95_ = NULL;
		GXmlGDocument* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		gchar* _tmp100_ = NULL;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp101_ = NULL;
		GXmlNode* _tmp102_ = NULL;
		GXmlNode* _tmp103_ = NULL;
		GXmlElement* _tmp104_ = NULL;
		GXmlNode* b3 = NULL;
		GXmlElement* _tmp105_ = NULL;
		GXmlNode* _tmp106_ = NULL;
		GXmlNode* _tmp107_ = NULL;
		GXmlNode* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		gchar* _tmp111_ = NULL;
		gdouble _tmp112_ = 0.0;
		gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp115_ = NULL;
		GXmlSerializableFloat* _tmp116_ = NULL;
		GXmlSerializableFloat* _tmp117_ = NULL;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp118_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp119_ = NULL;
		GXmlGDocument* _tmp120_ = NULL;
		GXmlNode* _tmp121_ = NULL;
		GXmlNode* _tmp122_ = NULL;
		GXmlGDocument* _tmp123_ = NULL;
		gchar* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
		gchar* _tmp126_ = NULL;
		gchar* _tmp127_ = NULL;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp128_ = NULL;
		GXmlNode* _tmp129_ = NULL;
		GXmlNode* _tmp130_ = NULL;
		GXmlElement* _tmp131_ = NULL;
		GXmlNode* b4 = NULL;
		GXmlNode* _tmp132_ = NULL;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp0_ = serializable_property_float_test_float_node_new ();
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		bn = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc = _tmp1_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp2_ = bn;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp3_ = doc;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp5_ = _tmp4_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp5_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 492 "SerializablePropertyFloatTest.c"
			goto __catch23_g_error;
		}
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp6_ = doc;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("XML:\n", _tmp8_, NULL);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp11_ = doc;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (_tmp14_ == NULL) {
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp13_);
#line 523 "SerializablePropertyFloatTest.c"
		}
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		element = _tmp14_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp15_ = element;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "FloatValue");
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		b = _tmp16_;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp17_ = b;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp17_ == NULL, "b == null");
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp18_ = element;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		s = _tmp19_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp20_ = s;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp20_ == NULL, "s == null");
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp21_ = bn;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp22_ = gxml_serializable_float_new ();
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp23_ = _tmp22_;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_float_value (_tmp21_, _tmp23_);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp23_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp24_ = bn;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp25_ = serializable_property_float_test_float_node_get_float_value (_tmp24_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp26_ = _tmp25_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_float_set_value (_tmp26_, (gfloat) 233.014);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp27_ = gxml_gdocument_new ();
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc2 = _tmp27_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp28_ = bn;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp29_ = doc2;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp30_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp28_, (GXmlNode*) _tmp29_, &_inner_error_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp31_ = _tmp30_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp31_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 593 "SerializablePropertyFloatTest.c"
			goto __catch23_g_error;
		}
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp32_ = doc2;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp33_ = gxml_gnode_to_string ((GXmlGNode*) _tmp32_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp34_ = _tmp33_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp35_ = g_strconcat ("XML2:\n", _tmp34_, NULL);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp36_ = _tmp35_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp36_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp36_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp34_);
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp37_ = doc2;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) _tmp37_);
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp39_ = _tmp38_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp40_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp39_) : NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (_tmp40_ == NULL) {
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp39_);
#line 624 "SerializablePropertyFloatTest.c"
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		element2 = _tmp40_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp41_ = element2;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp42_ = gxml_element_get_attr (_tmp41_, "FloatValue");
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		b2 = _tmp42_;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp43_ = b2;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp43_ != NULL, "b2 != null");
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp44_ = bn;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp45_ = serializable_property_float_test_float_node_get_float_value (_tmp44_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp46_ = _tmp45_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp47_ = gxml_serializable_float_get_value (_tmp46_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp47_ == ((gfloat) 233.014), "bn.float_value.get_value () == (float) 233.014");
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp48_ = b2;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp49_ = gxml_node_get_value (_tmp48_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp50_ = _tmp49_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp51_ = _tmp50_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp52_ = g_strconcat ("Value in xml: ", _tmp51_, NULL);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp53_ = _tmp52_;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp53_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp53_);
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp51_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp54_ = bn;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp55_ = serializable_property_float_test_float_node_get_float_value (_tmp54_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp56_ = _tmp55_;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp57_ = gxml_serializable_float_get_value (_tmp56_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp58_ = g_strdup_printf ("%g", _tmp57_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp59_ = _tmp58_;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp60_ = g_strconcat ("Value in double class: ", _tmp59_, NULL);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp61_ = _tmp60_;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp61_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp61_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp59_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp62_ = b2;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp63_ = gxml_node_get_value (_tmp62_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp64_ = _tmp63_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp65_ = _tmp64_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp66_ = double_parse (_tmp65_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp67_ = g_strdup_printf ("Value in xml formated %3.3f", _tmp66_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp68_ = _tmp67_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp68_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp68_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp65_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp69_ = b2;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp70_ = gxml_node_get_value (_tmp69_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp71_ = _tmp70_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp72_ = _tmp71_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp73_ = double_parse (_tmp72_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp74_ = g_strdup_printf ("%3.3f", _tmp73_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp75_ = _tmp74_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp75_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp75_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp72_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp76_ = b2;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp77_ = gxml_node_get_value (_tmp76_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp78_ = _tmp77_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp79_ = _tmp78_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp80_ = double_parse (_tmp79_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp81_ = g_strdup_printf ("%3.3f", _tmp80_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp82_ = _tmp81_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp82_, "233.014") == 0, "\"%3.3f\".printf (double.parse (b2.value)) == \"233.014\"");
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp82_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp79_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp83_ = bn;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp84_ = serializable_property_float_test_float_node_get_float_value (_tmp83_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp85_ = _tmp84_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp86_ = gxml_serializable_double_format ((GXmlSerializableDouble*) _tmp85_, "%3.3f");
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp87_ = _tmp86_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "233.014") == 0, "bn.float_value.format (\"%3.3f\") == \"233.014\"");
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp87_);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp88_ = bn;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp89_ = serializable_property_float_test_float_node_get_float_value (_tmp88_);
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp90_ = _tmp89_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_float_set_value (_tmp90_, (gfloat) (-1.013));
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp91_ = gxml_gdocument_new ();
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc3 = _tmp91_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp92_ = bn;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp93_ = doc3;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp94_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp92_, (GXmlNode*) _tmp93_, &_inner_error_);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp95_ = _tmp94_;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp95_);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc3);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b2);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element2);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 804 "SerializablePropertyFloatTest.c"
			goto __catch23_g_error;
		}
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp96_ = doc3;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp97_ = gxml_gnode_to_string ((GXmlGNode*) _tmp96_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp98_ = _tmp97_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp99_ = g_strconcat ("XML3:\n", _tmp98_, NULL);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp100_ = _tmp99_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp100_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp100_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp98_);
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp101_ = doc3;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp102_ = gxml_document_get_root ((GXmlDocument*) _tmp101_);
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp103_ = _tmp102_;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp104_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp103_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp103_) : NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (_tmp104_ == NULL) {
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp103_);
#line 835 "SerializablePropertyFloatTest.c"
		}
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		element3 = _tmp104_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp105_ = element3;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp106_ = gxml_element_get_attr (_tmp105_, "FloatValue");
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		b3 = _tmp106_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp107_ = b3;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp107_ != NULL, "b3 != null");
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp108_ = b3;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp109_ = gxml_node_get_value (_tmp108_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp110_ = _tmp109_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp111_ = _tmp110_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp112_ = double_parse (_tmp111_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp113_ = g_strdup_printf ("%2.3f", _tmp112_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp114_ = _tmp113_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp114_, "-1.013") == 0, "\"%2.3f\".printf (double.parse (b3.value)) == \"-1.013\"");
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp114_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp111_);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp115_ = bn;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp116_ = serializable_property_float_test_float_node_get_float_value (_tmp115_);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp117_ = _tmp116_;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp117_, NULL);
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp118_ = gxml_gdocument_new ();
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc4 = _tmp118_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp119_ = bn;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp120_ = doc4;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp121_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp119_, (GXmlNode*) _tmp120_, &_inner_error_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp122_ = _tmp121_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp122_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc4);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b3);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element3);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc3);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b2);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element2);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 917 "SerializablePropertyFloatTest.c"
			goto __catch23_g_error;
		}
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp123_ = doc4;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp124_ = gxml_gnode_to_string ((GXmlGNode*) _tmp123_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp125_ = _tmp124_;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp126_ = g_strconcat ("XML3:\n", _tmp125_, NULL);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp127_ = _tmp126_;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp127_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp127_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp125_);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp128_ = doc4;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp129_ = gxml_document_get_root ((GXmlDocument*) _tmp128_);
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp130_ = _tmp129_;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp131_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp130_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp130_) : NULL;
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (_tmp131_ == NULL) {
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp130_);
#line 948 "SerializablePropertyFloatTest.c"
		}
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		element4 = _tmp131_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp132_ = gxml_element_get_attr (element4, "FloatValue");
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		b4 = _tmp132_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (b4 == NULL, "b4 == null");
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (s);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (bn);
#line 986 "SerializablePropertyFloatTest.c"
	}
	goto __finally23;
	__catch23_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp133_ = NULL;
		const gchar* _tmp134_ = NULL;
		gchar* _tmp135_ = NULL;
		gchar* _tmp136_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		e = _inner_error_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_inner_error_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp133_ = e->message;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp134_ = string_to_string (_tmp133_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp135_ = g_strconcat ("ERROR: ", _tmp134_, NULL);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp136_ = _tmp135_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp136_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp136_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1016 "SerializablePropertyFloatTest.c"
	}
	__finally23:
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		return;
#line 1027 "SerializablePropertyFloatTest.c"
	}
}


static void ___lambda140__gtest_func (void) {
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	__lambda140_ ();
#line 1035 "SerializablePropertyFloatTest.c"
}


static void __lambda141_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyFloatTestFloatNode* f = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp4_ = NULL;
		GXmlSerializableFloat* _tmp5_ = NULL;
		GXmlSerializableFloat* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp11_ = NULL;
		GXmlSerializableFloat* _tmp12_ = NULL;
		GXmlSerializableFloat* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp16_ = NULL;
		GXmlSerializableFloat* _tmp17_ = NULL;
		GXmlSerializableFloat* _tmp18_ = NULL;
		gfloat _tmp19_ = 0.0F;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp24_ = NULL;
		GXmlSerializableFloat* _tmp25_ = NULL;
		GXmlSerializableFloat* _tmp26_ = NULL;
		gfloat _tmp27_ = 0.0F;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"3.1416\"/>", 0, &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1082 "SerializablePropertyFloatTest.c"
			goto __catch24_g_error;
		}
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		f = _tmp1_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp2_ = f;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (f);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1101 "SerializablePropertyFloatTest.c"
			goto __catch24_g_error;
		}
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp4_ = f;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp11_ = f;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "3.1416") == 0, "f.float_value.get_serializable_property_value () == \"3.1416\"");
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp16_ = f;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_serializable_float_get_value (_tmp18_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp20_ = g_strdup_printf ("%g", _tmp19_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp21_ = _tmp20_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp22_ = g_strconcat ("Actual value parse: ", _tmp21_, NULL);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp23_ = _tmp22_;
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp23_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp23_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp21_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp24_ = f;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp25_ = serializable_property_float_test_float_node_get_float_value (_tmp24_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp26_ = _tmp25_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp27_ = gxml_serializable_float_get_value (_tmp26_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp28_ = g_strdup_printf ("%2.4f", (gdouble) _tmp27_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp29_ = _tmp28_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp30_ = g_strdup_printf ("%2.4f", 3.1416);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp31_ = _tmp30_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, _tmp31_) == 0, "\"%2.4f\".printf (f.float_value.get_value ()) == \"%2.4f\".printf (3.1416)");
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp31_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp29_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (f);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1186 "SerializablePropertyFloatTest.c"
	}
	goto __finally24;
	__catch24_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		e = _inner_error_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_inner_error_ = NULL;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp32_ = e->message;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp33_ = string_to_string (_tmp32_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp34_ = g_strconcat ("ERROR: ", _tmp33_, NULL);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp35_ = _tmp34_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp35_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp35_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1216 "SerializablePropertyFloatTest.c"
	}
	__finally24:
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		return;
#line 1227 "SerializablePropertyFloatTest.c"
	}
}


static void ___lambda141__gtest_func (void) {
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	__lambda141_ ();
#line 1235 "SerializablePropertyFloatTest.c"
}


static void __lambda142_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyFloatTestFloatNode* d = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp4_ = NULL;
		GXmlSerializableFloat* _tmp5_ = NULL;
		GXmlSerializableFloat* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp11_ = NULL;
		GXmlSerializableFloat* _tmp12_ = NULL;
		GXmlSerializableFloat* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp16_ = NULL;
		GXmlSerializableFloat* _tmp17_ = NULL;
		GXmlSerializableFloat* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gdouble _tmp21_ = 0.0;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp26_ = NULL;
		GXmlSerializableFloat* _tmp27_ = NULL;
		GXmlSerializableFloat* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gdouble _tmp31_ = 0.0;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp34_ = NULL;
		GXmlSerializableFloat* _tmp35_ = NULL;
		GXmlSerializableFloat* _tmp36_ = NULL;
		gfloat _tmp37_ = 0.0F;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp40_ = NULL;
		GXmlSerializableFloat* _tmp41_ = NULL;
		GXmlSerializableFloat* _tmp42_ = NULL;
		gfloat _tmp43_ = 0.0F;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gdouble _tmp46_ = 0.0;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"3.1416\"/>", 0, &_inner_error_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1299 "SerializablePropertyFloatTest.c"
			goto __catch25_g_error;
		}
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		d = _tmp1_;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp2_ = d;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (d);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1318 "SerializablePropertyFloatTest.c"
			goto __catch25_g_error;
		}
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp4_ = d;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp11_ = d;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "3.1416") == 0, "d.float_value.get_serializable_property_value () == \"3.1416\"");
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp16_ = d;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp18_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp20_ = _tmp19_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp21_ = double_parse (_tmp20_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp22_ = g_strdup_printf ("%2.4f", _tmp21_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp23_ = _tmp22_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp24_ = g_strconcat ("Actual value parse: ", _tmp23_, NULL);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp25_ = _tmp24_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp25_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp25_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp23_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp20_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp26_ = d;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp27_ = serializable_property_float_test_float_node_get_float_value (_tmp26_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp28_ = _tmp27_;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp29_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp28_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp30_ = _tmp29_;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp31_ = double_parse (_tmp30_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp32_ = g_strdup_printf ("%2.4f", _tmp31_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp33_ = _tmp32_;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "3.1416") == 0, "\"%2.4f\".printf (double.parse (d.float_value.get_serializable_property_value ())) == \"3.1416\"");
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp33_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp30_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp34_ = d;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp35_ = serializable_property_float_test_float_node_get_float_value (_tmp34_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp36_ = _tmp35_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp37_ = gxml_serializable_float_get_value (_tmp36_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp38_ = g_strdup_printf ("Value comparation: %2.4f", (gdouble) _tmp37_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp39_ = _tmp38_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp39_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp39_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp40_ = d;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp41_ = serializable_property_float_test_float_node_get_float_value (_tmp40_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp42_ = _tmp41_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp43_ = gxml_serializable_float_get_value (_tmp42_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp44_ = g_strdup_printf ("%2.4f", (gdouble) _tmp43_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp45_ = _tmp44_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp46_ = double_parse ("3.1416");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp47_ = g_strdup_printf ("%2.4f", _tmp46_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp48_ = _tmp47_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, _tmp48_) == 0, "\"%2.4f\".printf (d.float_value.get_value ()) == \"%2.4f\".printf (double.parse (\"3.1416\"))");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp48_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp45_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (d);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1449 "SerializablePropertyFloatTest.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		const gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		e = _inner_error_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_inner_error_ = NULL;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp49_ = e->message;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp50_ = string_to_string (_tmp49_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp51_ = g_strconcat ("ERROR: ", _tmp50_, NULL);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp52_ = _tmp51_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp52_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp52_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1479 "SerializablePropertyFloatTest.c"
	}
	__finally25:
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		return;
#line 1490 "SerializablePropertyFloatTest.c"
	}
}


static void ___lambda142__gtest_func (void) {
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	__lambda142_ ();
#line 1498 "SerializablePropertyFloatTest.c"
}


static void __lambda143_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyFloatTestFloatNode* d = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp4_ = NULL;
		GXmlSerializableFloat* _tmp5_ = NULL;
		GXmlSerializableFloat* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp11_ = NULL;
		GXmlSerializableFloat* _tmp12_ = NULL;
		GXmlSerializableFloat* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp16_ = NULL;
		GXmlSerializableFloat* _tmp17_ = NULL;
		GXmlSerializableFloat* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gdouble _tmp21_ = 0.0;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp26_ = NULL;
		GXmlSerializableFloat* _tmp27_ = NULL;
		GXmlSerializableFloat* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gdouble _tmp31_ = 0.0;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"a\"/>", 0, &_inner_error_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1547 "SerializablePropertyFloatTest.c"
			goto __catch26_g_error;
		}
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 145 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		d = _tmp1_;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp2_ = d;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (d);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1566 "SerializablePropertyFloatTest.c"
			goto __catch26_g_error;
		}
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp4_ = d;
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp11_ = d;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "a") == 0, "d.float_value.get_serializable_property_value () == \"a\"");
#line 148 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp16_ = d;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp18_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp20_ = _tmp19_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp21_ = double_parse (_tmp20_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp22_ = g_strdup_printf ("%2.4f", _tmp21_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp23_ = _tmp22_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp24_ = g_strconcat ("Actual value parse: ", _tmp23_, NULL);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp25_ = _tmp24_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp25_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp25_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp23_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp20_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp26_ = d;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp27_ = serializable_property_float_test_float_node_get_float_value (_tmp26_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp28_ = _tmp27_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp29_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp28_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp30_ = _tmp29_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp31_ = double_parse (_tmp30_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp32_ = g_strdup_printf ("%2.4f", _tmp31_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp33_ = _tmp32_;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "0.0000") == 0, "\"%2.4f\".printf (double.parse (d.float_value.get_serializable_property_value ())) == \"0.0000\"");
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp33_);
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp30_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (d);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1657 "SerializablePropertyFloatTest.c"
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		e = _inner_error_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_inner_error_ = NULL;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp34_ = e->message;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp35_ = string_to_string (_tmp34_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_tmp37_ = _tmp36_;
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp37_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp37_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1687 "SerializablePropertyFloatTest.c"
	}
	__finally26:
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		return;
#line 1698 "SerializablePropertyFloatTest.c"
	}
}


static void ___lambda143__gtest_func (void) {
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	__lambda143_ ();
#line 1706 "SerializablePropertyFloatTest.c"
}


void serializable_property_float_test_add_tests (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/basic", ___lambda139__gtest_func);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/changes", ___lambda140__gtest_func);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/basic", ___lambda141__gtest_func);
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/aditional", ___lambda142__gtest_func);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/bad-value", ___lambda143__gtest_func);
#line 1721 "SerializablePropertyFloatTest.c"
}


SerializablePropertyFloatTest* serializable_property_float_test_construct (GType object_type) {
	SerializablePropertyFloatTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return self;
#line 1731 "SerializablePropertyFloatTest.c"
}


SerializablePropertyFloatTest* serializable_property_float_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return serializable_property_float_test_construct (TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST);
#line 1738 "SerializablePropertyFloatTest.c"
}


static gchar* serializable_property_float_test_float_node_real_node_name (GXmlSerializableObjectModel* base) {
	SerializablePropertyFloatTestFloatNode * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = g_strdup ("FloatNode");
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return result;
#line 1754 "SerializablePropertyFloatTest.c"
}


static gchar* serializable_property_float_test_float_node_real_to_string (GXmlSerializableObjectModel* base) {
	SerializablePropertyFloatTestFloatNode * self;
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp1_ = g_type_name (_tmp0_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	result = _tmp2_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return result;
#line 1776 "SerializablePropertyFloatTest.c"
}


static gboolean serializable_property_float_test_float_node_real_property_use_nick (GXmlSerializableObjectModel* base) {
	SerializablePropertyFloatTestFloatNode * self;
	gboolean result = FALSE;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	result = TRUE;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return result;
#line 1789 "SerializablePropertyFloatTest.c"
}


SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_construct (GType object_type) {
	SerializablePropertyFloatTestFloatNode * self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) gxml_serializable_object_model_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return self;
#line 1799 "SerializablePropertyFloatTest.c"
}


SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return serializable_property_float_test_float_node_construct (SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE);
#line 1806 "SerializablePropertyFloatTest.c"
}


GXmlSerializableFloat* serializable_property_float_test_float_node_get_float_value (SerializablePropertyFloatTestFloatNode* self) {
	GXmlSerializableFloat* result;
	GXmlSerializableFloat* _tmp0_ = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = self->priv->_float_value;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return result;
#line 1821 "SerializablePropertyFloatTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1828 "SerializablePropertyFloatTest.c"
}


void serializable_property_float_test_float_node_set_float_value (SerializablePropertyFloatTestFloatNode* self, GXmlSerializableFloat* value) {
	GXmlSerializableFloat* _tmp0_ = NULL;
	GXmlSerializableFloat* _tmp1_ = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = value;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_g_object_unref0 (self->priv->_float_value);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self->priv->_float_value = _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_object_notify ((GObject *) self, "float-value");
#line 1847 "SerializablePropertyFloatTest.c"
}


const gchar* serializable_property_float_test_float_node_get_name (SerializablePropertyFloatTestFloatNode* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	return result;
#line 1862 "SerializablePropertyFloatTest.c"
}


void serializable_property_float_test_float_node_set_name (SerializablePropertyFloatTestFloatNode* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp0_ = value;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_g_free0 (self->priv->_name);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self->priv->_name = _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 1881 "SerializablePropertyFloatTest.c"
}


static void serializable_property_float_test_float_node_class_init (SerializablePropertyFloatTestFloatNodeClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	serializable_property_float_test_float_node_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_type_class_add_private (klass, sizeof (SerializablePropertyFloatTestFloatNodePrivate));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_node_name;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_to_string;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*)(GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_property_use_nick;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_float_test_float_node_get_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_float_test_float_node_set_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_float_test_float_node_finalize;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE, g_param_spec_object ("float-value", "FloatValue", "float-value", GXML_TYPE_SERIALIZABLE_FLOAT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1906 "SerializablePropertyFloatTest.c"
}


static void serializable_property_float_test_float_node_instance_init (SerializablePropertyFloatTestFloatNode * self) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self->priv = SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_GET_PRIVATE (self);
#line 1913 "SerializablePropertyFloatTest.c"
}


static void serializable_property_float_test_float_node_finalize (GObject* obj) {
	SerializablePropertyFloatTestFloatNode * self;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_g_object_unref0 (self->priv->_float_value);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	_g_free0 (self->priv->_name);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (serializable_property_float_test_float_node_parent_class)->finalize (obj);
#line 1927 "SerializablePropertyFloatTest.c"
}


GType serializable_property_float_test_float_node_get_type (void) {
	static volatile gsize serializable_property_float_test_float_node_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_float_test_float_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyFloatTestFloatNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_float_test_float_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyFloatTestFloatNode), 0, (GInstanceInitFunc) serializable_property_float_test_float_node_instance_init, NULL };
		GType serializable_property_float_test_float_node_type_id;
		serializable_property_float_test_float_node_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyFloatTestFloatNode", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_float_test_float_node_type_id__volatile, serializable_property_float_test_float_node_type_id);
	}
	return serializable_property_float_test_float_node_type_id__volatile;
}


static void _vala_serializable_property_float_test_float_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializablePropertyFloatTestFloatNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_value_set_object (value, serializable_property_float_test_float_node_get_float_value (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		g_value_set_string (value, serializable_property_float_test_float_node_get_name (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 1960 "SerializablePropertyFloatTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 1966 "SerializablePropertyFloatTest.c"
	}
}


static void _vala_serializable_property_float_test_float_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializablePropertyFloatTestFloatNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_float_value (self, g_value_get_object (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_name (self, g_value_get_string (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 1988 "SerializablePropertyFloatTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
		break;
#line 1994 "SerializablePropertyFloatTest.c"
	}
}


static void serializable_property_float_test_class_init (SerializablePropertyFloatTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyFloatTest.vala"
	serializable_property_float_test_parent_class = g_type_class_peek_parent (klass);
#line 2002 "SerializablePropertyFloatTest.c"
}


static void serializable_property_float_test_instance_init (SerializablePropertyFloatTest * self) {
}


/**
 *
 *  SerializablePropertyFloatTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_property_float_test_get_type (void) {
	static volatile gsize serializable_property_float_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_float_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyFloatTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_float_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyFloatTest), 0, (GInstanceInitFunc) serializable_property_float_test_instance_init, NULL };
		GType serializable_property_float_test_type_id;
		serializable_property_float_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyFloatTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_float_test_type_id__volatile, serializable_property_float_test_type_id);
	}
	return serializable_property_float_test_type_id__volatile;
}



